#!/bin/sh
#copyright	"%c%"
#ident	"@(#)opensrc:src/samba/samba.sh /main/uw714mp/8"

#
# This directory contains:
#
# dist/			Source files from samba-3.0.10 distribution.
# patches/*		Patches to be applied.
# samba.sh		Build script (this file).
#
# samba.init		/etc/init.d script.
# samba.pam		/etc/pam.d/samba file.
# samba.inetd.sed	Sed script to modify /etc/inet/inetd.conf file.
# samba.services.sed	Sed script to modify /etc/inet/services file. 
# samba.desktop		Docview glue.
#

set -x

# We need gawk.
AWK=/usr/add-on/public/bin/gawk; export AWK
[ ! -x $AWK ] && {
	echo "ERROR: $AWK not found" >&2
	exit 1
}

set -e

# Apply patches.
for patch in 3.0.10-port
do
	[ -f patches/${patch}.applied ] || {
		/bin/patch -c -p0 -i patches/${patch}.patch
		/bin/date > patches/${patch}.applied
	}
done

#
# Copy NSS files.
# Note: Do this before configure so that configure finds nss.h in xenv.
#
/bin/cp patches/nss.h $TOOLS/usr/include/
/bin/cp patches/nss_compat.c dist/source/nsswitch/
/bin/cp patches/winbind_nss_uw7.c dist/source/nsswitch/

#
# Compiler can optimize out function calls but smbd/msdfs.c has a bad
# optimize, so turn it off.
#
# TODO
# Try to fix smbd/msdfs.c.
#
samba_cv_optimize_out_funcation_calls=no
export samba_cv_optimize_out_funcation_calls

cd dist/source/

#
# Configure.
#
# Use --with-libsmbclient otherwise static library does not get installed.
#
# TODO
# 1. We have bigcrypt() in libcrypt but configure does not detect it.
# 2. We have cups, explore enabling it in next release.
# 3. We have ldap, explore enabling it in next release.
#
./configure \
	--cache-file=/dev/null \
	--prefix=/usr/lib/samba \
	--disable-cups \
	--with-mandir=/usr/man \
	--with-libiconv=/usr \
	--without-ldap \
	--without-ads \
	--with-pam \
	--with-pam_smbpass \
	--with-syslog \
	--with-utmp \
	--with-libsmbclient \
	--with-winbind \
	--with-included-popt

#
# Make and install.
# The default shell is /bin/sh which does not work, so use /bin/ksh.
#
$MAKE SHELL=/bin/ksh DESTDIR=$ROOT/$MACH install

# Install pam and winbind files.
$INSTALL -d $ROOT/$MACH/usr/lib/security
$INSTALL -d $ROOT/$MACH/usr/lib/nss
$INSTALL bin/pam_smbpass.so $ROOT/$MACH/usr/lib/security/
$INSTALL nsswitch/winbind.so $ROOT/$MACH/usr/lib/nss/
$INSTALL nsswitch/wins.so $ROOT/$MACH/usr/lib/nss/
$INSTALL nsswitch/pam_winbind.so $ROOT/$MACH/usr/lib/security/

cd ..

# Install a sample config file.
$INSTALL examples/smb.conf.default $ROOT/$MACH/usr/lib/samba/lib/

# Install COPYING file.
$INSTALL -d $ROOT/$MACH/usr/share/samba
$INSTALL COPYING $ROOT/$MACH/usr/share/samba/

# Install WHATSNEW.txt file. (It is referenced by samba doc).
$INSTALL WHATSNEW.txt $ROOT/$MACH/usr/lib/samba/swat/help/

cd ..

# Install startup script.
$INSTALL -d $ROOT/$MACH/etc/init.d
$INSTALL samba.init $ROOT/$MACH/etc/init.d/samba

# Install pam config file.
$INSTALL -d $ROOT/$MACH/etc/pam.d
$INSTALL samba.pam $ROOT/$MACH/etc/pam.d/samba

# Install sed scripts.
$INSTALL -d $ROOT/$MACH/etc/inet
$INSTALL samba.inetd.sed $ROOT/$MACH/etc/inet/
$INSTALL samba.services.sed $ROOT/$MACH/etc/inet/

# Install docview glue.
DOSgroup=/usr/share/meta/doc/HelpTopics/DOShome/DOSgroup
$INSTALL -d $ROOT/$MACH/$DOSgroup
$INSTALL samba.desktop $ROOT/$MACH/$DOSgroup/samba.desktop

# Remove nss.h from cross environment so that others do not pick it up.
/bin/rm $TOOLS/usr/include/nss.h

exit 0
